@@ -1,13 +1,10 @@
 package MooseX::Storage::Engine;
-{
-  $MooseX::Storage::Engine::VERSION = '0.45';
-}
-BEGIN {
-  $MooseX::Storage::Engine::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: The meta-engine to handle collapsing and expanding objects
+$MooseX::Storage::Engine::VERSION = '0.47';
 use Moose;
-use Scalar::Util qw(refaddr);
+use Scalar::Util qw(refaddr blessed);
+use Carp 'confess';
+use namespace::autoclean;
 
 # the class marker when
 # serializing an object.
@@ -61,14 +58,16 @@ sub expand_object {
 sub collapse_attribute {
     my ($self, $attr, $options)  = @_;
     my $value = $self->collapse_attribute_value($attr, $options);
-    return if !defined($value);
+
+    return unless $attr->has_value($self->object);
     $self->storage->{$attr->name} = $value;
 }
 
 sub expand_attribute {
     my ($self, $attr, $data, $options)  = @_;
+    return unless exists $data->{$attr->name};
     my $value = $self->expand_attribute_value($attr, $data->{$attr->name}, $options);
-    $self->storage->{$attr->name} = defined $value ? $value : return;
+    $self->storage->{$attr->name} = $value;
 }
 
 sub collapse_attribute_value {
@@ -377,19 +376,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Florian Ragwitz Johannes Plunien Jonathan Rockway Yu Jos
-Boumans Karen Etheridge Ricardo Signes Robert Boone Shawn M Moore Tomas
-Doran Cory Yuval Kogman Watson Dagfinn Ilmari Mannsåker David Golden
-Steinbrunner
-
 =head1 NAME
 
 MooseX::Storage::Engine - The meta-engine to handle collapsing and expanding objects
 
 =head1 VERSION
 
-version 0.45
+version 0.47
 
 =head1 DESCRIPTION
 
