@@ -1,14 +1,9 @@
 package MooseX::Storage::Format::Storable;
-{
-  $MooseX::Storage::Format::Storable::VERSION = '0.45';
-}
-BEGIN {
-  $MooseX::Storage::Format::Storable::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A Storable serialization role
+$MooseX::Storage::Format::Storable::VERSION = '0.47';
 use Moose::Role;
-
 use Storable ();
+use namespace::autoclean;
 
 requires 'pack';
 requires 'unpack';
@@ -33,19 +28,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Florian Ragwitz Johannes Plunien Jonathan Rockway Yu Jos
-Boumans Karen Etheridge Ricardo Signes Robert Boone Shawn M Moore Tomas
-Doran Cory Yuval Kogman Watson Dagfinn Ilmari Mannsåker David Golden
-Steinbrunner IPC Storable's
-
 =head1 NAME
 
 MooseX::Storage::Format::Storable - A Storable serialization role
 
 =head1 VERSION
 
-version 0.45
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -73,10 +62,14 @@ version 0.45
 
 =head1 DESCRIPTION
 
+=for stopwords IPC
+
 This module will C<thaw> and C<freeze> Moose classes using Storable. It
 uses C<Storable::nfreeze> by default so that it can be easily used
 in IPC scenarios across machines or just locally.
 
+=for stopwords Storable's
+
 One important thing to note is that this module does not mix well
 with the IO modules. The structures that C<freeze> and C<thaw> deal with
 are Storable's memory representation, and (as far as I know) that
